#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: types.py
@time: 2022/09/15
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.

STRING = 0
AUDIO = 1
IMAGE = 2
VIDEO = 3

DataText = 0  # 文本数据
DataAudio = 1  # 音频数据
DataImage = 2  # 图像数据
DataVideo = 3  # 视频数据

Types = {
    0: "text",
    1: "audio",
    2: "image",
    3: "video"
}

DataBegin = 0  # 首数据
DataContinue = 1  # 中间数据
DataEnd = 2  # 尾数据
DataOnce = 3  # 非会话单次输入输出

Status = {
    0: "begin",
    1: "continue",
    2: "end",
    3: "once"
}

Once = DataOnce

# 并行模式
THREAD_MODE = "thread"  # 默认模式，

PROCESS_MODE = "process"  # 当前不可用



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: test
@time: 2023/03/11
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
import gradio as gr

with gr.Blocks() as demo:
    a = gr.Button()
    b = gr.Button(interactive=True)

    a.click(lambda: gr.Button.update("hi", interactive=False), None, b)

    gr.Button(variant="primary")
    gr.Button(variant="primary", interactive=False)

    gr.Button(variant="stop")
    gr.Button(variant="stop", interactive=False)

demo.launch()


#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: component.py
@time: 2023/01/11
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.

import gradio as gr
from aiges.schema.types import *


def infer(image):
    result = image
    return result


class AISchemaGradioMapper(object):
    def __init__(self, _schema):
        self._schema = _schema
        self.inputbodymap = {
            "image": gr.Image,
            "audio": gr.Audio,
            "text": gr.Text,
        }

    def new_ui_by_schema(self, input_schema_json, output_schema_json):
        params = input_schema_json['definitions']['Paramodel']
        for p, d in params['properties'].items():
            if "type" not in d:
                continue
            if d['type'] == "string":
                text = gr.Text(label=p, type='text', visible=True, show_label=True)
                self.gr_inputs.append(text)
            elif d['type'] == "integer":
                pnum = gr.Number(label=p, visible=True, show_label=True)
                self.gr_inputs.append(pnum)
            elif d['type'] == "boolean":
                it = gr.Checkbox(label=p, visible=True, show_label=True)
                self.gr_inputs.append(it)
        pass

    def new_gradio_component(self, m: BaseModel, key: str):
        print(type(m))
        print(dir(m))

        if isinstance(m, ImageField):
            image = gr.Image(label=key, type='filepath', visible=True, show_label=True)
            self.gr_inputs.append(image)
        elif isinstance(m, TextField):
            text = gr.Text(label=key, type='text', visible=True, show_label=True)
            self.gr_inputs.append(text)

        elif isinstance(m, AudioField):
            audio = gr.Audio(label=key, type='numpy', visible=True, show_label=True)
            self.gr_inputs.append(audio)
        elif isinstance(m, str):
            pstr = gr.Textbox(label=key, type='text', visible=True, show_label=True)
            self.gr_inputs.append(pstr)
        elif isinstance(m, bool):
            pbool = gr.Checkbox(label=key, visible=True, show_label=True)
            self.gr_inputs.append(pbool)

        elif isinstance(m, int) | isinstance(m, float):
            pnum = gr.Number(label=key, visible=True, show_label=True)
            self.gr_inputs.append(pnum)

    def run(self):
        with gr.Blocks() as self.gr_demo:
            title = gr.Markdown("""
            # Gradio Demo ASF aiges demo
            """)
            self.gr_inputs = []
            self.gr_outputs = []
            title = gr.Markdown("""
               ## demo's input params(控制字段)
               """)
            with gr.Row(equal_height=True):
                # self._schema.schemainput.schema()['definitions']['Paramodel'] todo
                a = self._schema.schemainput.schema_json()
                self.new_ui_by_schema(self._schema.schemainput.schema(), self._schema.schemaoutput.schema())
        #                    for p in self._schema.schemainput.parameter.__fields__:
        #                        self.new_gradio_component(self._schema.schemainput.parameter.__dict__.get(p), p)

            title = gr.Markdown("""
            ## demo's input body(body输入)
            """)
            with gr.Row(equal_height=True):
                for f in self._schema.schemainput.payload.__fields__:
                    self.new_gradio_component(self._schema.schemainput.payload.__dict__.get(f), f)

            title = gr.Markdown("""
            ## demo's outputs (推理输出)
            """)
            with gr.Row(equal_height=True):
                for p in self._schema.schemaoutput.payload.__fields__:
                    self.new_gradio_component(self._schema.schemaoutput.payload.__dict__.get(p), p)

            run_button = gr.Button('Run')
            run_button.click(fn=infer, inputs=self.gr_inputs, outputs=self.gr_outputs)

        self.gr_demo.launch(share=False, server_name='0.0.0.0', server_port=7861)


class GradioComponent(object):
    def __init__(self, ai_schema):
        self._schema = ai_schema
        inputs = []
        self.ui = AISchemaGradioMapper(ai_schema)

    def prepareUI(self):
        pass

    def schemaToGradio(self):
        pass

    def run(self):
        self.ui.run()



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: aiges/protocol/xsf.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x18\x61iges/protocol/xsf.proto\x12\x05utils\"t\n\x07Session\x12\t\n\x01t\x18\x01 \x01(\t\x12\t\n\x01h\x18\x02 \x01(\t\x12&\n\x04sess\x18\x03 \x03(\x0b\x32\x18.utils.Session.SessEntry\x1a+\n\tSessEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"n\n\x08\x44\x61taMeta\x12\x0c\n\x04\x64\x61ta\x18\x01 \x01(\x0c\x12\'\n\x04\x64\x65sc\x18\x03 \x03(\x0b\x32\x19.utils.DataMeta.DescEntry\x1a+\n\tDescEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xa7\x01\n\x07ReqData\x12\n\n\x02op\x18\x01 \x01(\t\x12\x19\n\x01s\x18\x02 \x01(\x0b\x32\x0e.utils.Session\x12(\n\x05param\x18\x03 \x03(\x0b\x32\x19.utils.ReqData.ParamEntry\x12\x1d\n\x04\x64\x61ta\x18\x04 \x03(\x0b\x32\x0f.utils.DataMeta\x1a,\n\nParamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"\xbd\x01\n\x07ResData\x12\x0c\n\x04\x63ode\x18\x01 \x01(\x05\x12\x12\n\nerror_info\x18\x02 \x01(\t\x12\x19\n\x01s\x18\x03 \x01(\x0b\x32\x0e.utils.Session\x12(\n\x05param\x18\x04 \x03(\x0b\x32\x19.utils.ResData.ParamEntry\x12\x1d\n\x04\x64\x61ta\x18\x05 \x03(\x0b\x32\x0f.utils.DataMeta\x1a,\n\nParamEntry\x12\x0b\n\x03key\x18\x01 \x01(\t\x12\r\n\x05value\x18\x02 \x01(\t:\x02\x38\x01\"7\n\x07Request\x12\r\n\x05query\x18\x01 \x01(\t\x12\x0f\n\x07headers\x18\x02 \x01(\t\x12\x0c\n\x04\x62ody\x18\x03 \x01(\t\")\n\x08Response\x12\x0f\n\x07headers\x18\x01 \x01(\t\x12\x0c\n\x04\x62ody\x18\x02 \x01(\t23\n\x07XsfCall\x12(\n\x04\x63\x61ll\x12\x0e.utils.ReqData\x1a\x0e.utils.ResData\"\x00\x32\x39\n\x07ToolBox\x12.\n\tcmdserver\x12\x0e.utils.Request\x1a\x0f.utils.Response\"\x00\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'aiges.protocol.xsf_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _SESSION_SESSENTRY._options = None
  _SESSION_SESSENTRY._serialized_options = b'8\001'
  _DATAMETA_DESCENTRY._options = None
  _DATAMETA_DESCENTRY._serialized_options = b'8\001'
  _REQDATA_PARAMENTRY._options = None
  _REQDATA_PARAMENTRY._serialized_options = b'8\001'
  _RESDATA_PARAMENTRY._options = None
  _RESDATA_PARAMENTRY._serialized_options = b'8\001'
  _SESSION._serialized_start=35
  _SESSION._serialized_end=151
  _SESSION_SESSENTRY._serialized_start=108
  _SESSION_SESSENTRY._serialized_end=151
  _DATAMETA._serialized_start=153
  _DATAMETA._serialized_end=263
  _DATAMETA_DESCENTRY._serialized_start=220
  _DATAMETA_DESCENTRY._serialized_end=263
  _REQDATA._serialized_start=266
  _REQDATA._serialized_end=433
  _REQDATA_PARAMENTRY._serialized_start=389
  _REQDATA_PARAMENTRY._serialized_end=433
  _RESDATA._serialized_start=436
  _RESDATA._serialized_end=625
  _RESDATA_PARAMENTRY._serialized_start=389
  _RESDATA_PARAMENTRY._serialized_end=433
  _REQUEST._serialized_start=627
  _REQUEST._serialized_end=682
  _RESPONSE._serialized_start=684
  _RESPONSE._serialized_end=725
  _XSFCALL._serialized_start=727
  _XSFCALL._serialized_end=778
  _TOOLBOX._serialized_start=780
  _TOOLBOX._serialized_end=837
# @@protoc_insertion_point(module_scope)



from google.protobuf.internal import containers as _containers
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from typing import ClassVar as _ClassVar, Iterable as _Iterable, Mapping as _Mapping, Optional as _Optional, Union as _Union

DESCRIPTOR: _descriptor.FileDescriptor

class DataMeta(_message.Message):
    __slots__ = ["data", "desc"]
    class DescEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DATA_FIELD_NUMBER: _ClassVar[int]
    DESC_FIELD_NUMBER: _ClassVar[int]
    data: bytes
    desc: _containers.ScalarMap[str, str]
    def __init__(self, data: _Optional[bytes] = ..., desc: _Optional[_Mapping[str, str]] = ...) -> None: ...

class ReqData(_message.Message):
    __slots__ = ["data", "op", "param", "s"]
    class ParamEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    DATA_FIELD_NUMBER: _ClassVar[int]
    OP_FIELD_NUMBER: _ClassVar[int]
    PARAM_FIELD_NUMBER: _ClassVar[int]
    S_FIELD_NUMBER: _ClassVar[int]
    data: _containers.RepeatedCompositeFieldContainer[DataMeta]
    op: str
    param: _containers.ScalarMap[str, str]
    s: Session
    def __init__(self, op: _Optional[str] = ..., s: _Optional[_Union[Session, _Mapping]] = ..., param: _Optional[_Mapping[str, str]] = ..., data: _Optional[_Iterable[_Union[DataMeta, _Mapping]]] = ...) -> None: ...

class Request(_message.Message):
    __slots__ = ["body", "headers", "query"]
    BODY_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    QUERY_FIELD_NUMBER: _ClassVar[int]
    body: str
    headers: str
    query: str
    def __init__(self, query: _Optional[str] = ..., headers: _Optional[str] = ..., body: _Optional[str] = ...) -> None: ...

class ResData(_message.Message):
    __slots__ = ["code", "data", "error_info", "param", "s"]
    class ParamEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    CODE_FIELD_NUMBER: _ClassVar[int]
    DATA_FIELD_NUMBER: _ClassVar[int]
    ERROR_INFO_FIELD_NUMBER: _ClassVar[int]
    PARAM_FIELD_NUMBER: _ClassVar[int]
    S_FIELD_NUMBER: _ClassVar[int]
    code: int
    data: _containers.RepeatedCompositeFieldContainer[DataMeta]
    error_info: str
    param: _containers.ScalarMap[str, str]
    s: Session
    def __init__(self, code: _Optional[int] = ..., error_info: _Optional[str] = ..., s: _Optional[_Union[Session, _Mapping]] = ..., param: _Optional[_Mapping[str, str]] = ..., data: _Optional[_Iterable[_Union[DataMeta, _Mapping]]] = ...) -> None: ...

class Response(_message.Message):
    __slots__ = ["body", "headers"]
    BODY_FIELD_NUMBER: _ClassVar[int]
    HEADERS_FIELD_NUMBER: _ClassVar[int]
    body: str
    headers: str
    def __init__(self, headers: _Optional[str] = ..., body: _Optional[str] = ...) -> None: ...

class Session(_message.Message):
    __slots__ = ["h", "sess", "t"]
    class SessEntry(_message.Message):
        __slots__ = ["key", "value"]
        KEY_FIELD_NUMBER: _ClassVar[int]
        VALUE_FIELD_NUMBER: _ClassVar[int]
        key: str
        value: str
        def __init__(self, key: _Optional[str] = ..., value: _Optional[str] = ...) -> None: ...
    H_FIELD_NUMBER: _ClassVar[int]
    SESS_FIELD_NUMBER: _ClassVar[int]
    T_FIELD_NUMBER: _ClassVar[int]
    h: str
    sess: _containers.ScalarMap[str, str]
    t: str
    def __init__(self, t: _Optional[str] = ..., h: _Optional[str] = ..., sess: _Optional[_Mapping[str, str]] = ...) -> None: ...



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
"""Client and server classes corresponding to protobuf-defined services."""
import grpc

from aiges.protocol import xsf_pb2 as aiges_dot_protocol_dot_xsf__pb2


class XsfCallStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.call = channel.unary_unary(
                '/utils.XsfCall/call',
                request_serializer=aiges_dot_protocol_dot_xsf__pb2.ReqData.SerializeToString,
                response_deserializer=aiges_dot_protocol_dot_xsf__pb2.ResData.FromString,
                )


class XsfCallServicer(object):
    """Missing associated documentation comment in .proto file."""

    def call(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_XsfCallServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'call': grpc.unary_unary_rpc_method_handler(
                    servicer.call,
                    request_deserializer=aiges_dot_protocol_dot_xsf__pb2.ReqData.FromString,
                    response_serializer=aiges_dot_protocol_dot_xsf__pb2.ResData.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'utils.XsfCall', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class XsfCall(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def call(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/utils.XsfCall/call',
            aiges_dot_protocol_dot_xsf__pb2.ReqData.SerializeToString,
            aiges_dot_protocol_dot_xsf__pb2.ResData.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)


class ToolBoxStub(object):
    """Missing associated documentation comment in .proto file."""

    def __init__(self, channel):
        """Constructor.

        Args:
            channel: A grpc.Channel.
        """
        self.cmdserver = channel.unary_unary(
                '/utils.ToolBox/cmdserver',
                request_serializer=aiges_dot_protocol_dot_xsf__pb2.Request.SerializeToString,
                response_deserializer=aiges_dot_protocol_dot_xsf__pb2.Response.FromString,
                )


class ToolBoxServicer(object):
    """Missing associated documentation comment in .proto file."""

    def cmdserver(self, request, context):
        """Missing associated documentation comment in .proto file."""
        context.set_code(grpc.StatusCode.UNIMPLEMENTED)
        context.set_details('Method not implemented!')
        raise NotImplementedError('Method not implemented!')


def add_ToolBoxServicer_to_server(servicer, server):
    rpc_method_handlers = {
            'cmdserver': grpc.unary_unary_rpc_method_handler(
                    servicer.cmdserver,
                    request_deserializer=aiges_dot_protocol_dot_xsf__pb2.Request.FromString,
                    response_serializer=aiges_dot_protocol_dot_xsf__pb2.Response.SerializeToString,
            ),
    }
    generic_handler = grpc.method_handlers_generic_handler(
            'utils.ToolBox', rpc_method_handlers)
    server.add_generic_rpc_handlers((generic_handler,))


 # This class is part of an EXPERIMENTAL API.
class ToolBox(object):
    """Missing associated documentation comment in .proto file."""

    @staticmethod
    def cmdserver(request,
            target,
            options=(),
            channel_credentials=None,
            call_credentials=None,
            insecure=False,
            compression=None,
            wait_for_ready=None,
            timeout=None,
            metadata=None):
        return grpc.experimental.unary_unary(request, target, '/utils.ToolBox/cmdserver',
            aiges_dot_protocol_dot_xsf__pb2.Request.SerializeToString,
            aiges_dot_protocol_dot_xsf__pb2.Response.FromString,
            options, channel_credentials,
            insecure, call_credentials, compression, wait_for_ready, timeout, metadata)



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: types
@time: 2023/01/11
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
from enum import Enum
from pydantic import BaseModel, Field, create_model
from typing import Optional


from pydantic import BaseModel as PydanticBaseModel


# class BaseModel(PydanticBaseModel):
#     class Config:
#         arbitrary_types_allowed = True

# class BaseModel(BaseModel):
#     class Config:
#         arbitrary_types_allowed = True


class TextEncoding(str, Enum):
    utf8 = "utf8"
    gb2312 = "gb2312"
    gbk = "gbk"


class ImageEncoding(str, Enum):
    jpg = "jpg"
    png = "png"


class AudioEncoding(str, Enum):
    pcm = "pcm"
    raw = "raw"
    mp3 = "mp3"

class Compress(str, Enum):
    raw = "raw"
    gzip = "gzip"


class TextFormat(str, Enum):
    xml = "xml"
    plain = "plain"
    json = "json"


class DataStatus(int, Enum):
    First = 0
    Continue = 1
    Last = 2
    Once = 3

class StrParamField(BaseModel):
    maxLength: Optional[int]
    minLength: Optional[int]
    title :Optional[str]


class TextField(BaseModel):
    encoding: TextEncoding = Field(..., alias="encoding")
    compress: Compress = Field(..., alias="compress")
    format: TextFormat = Field(..., alias="format")
    status: DataStatus = Field(..., alias="status")
    text: str = Field(None, min_length=1, max_length=10485760)
    data_type: Optional[str] = Field("text")


class ImageField(BaseModel):
    encoding: ImageEncoding = Field(None, alias="encoding")
    status: DataStatus = Field(None, alias="status")
    image: str = Field(None, min_length=1, max_length=10485760)
    data_type: Optional[str] = Field("image")


class AudioField(BaseModel):
    encoding: AudioEncoding = Field(None, alias="encoding")
    status: DataStatus = Field(None, alias="status")
    audio: str = Field(None, min_length=1, max_length=10485760)
    data_type: Optional[str] = Field("audio")


class BoolParam(BaseModel):
    pass


class StringParam(BaseModel):
    pass



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: fixpool
@time: 2023/03/02
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
from aiges.concurrent.pool import Pool
from aiges.worker import Worker

class FixedPool(Pool):
    """
    a pool fixed size, for limit the objs
    """
    capacity = 1
    allocated = 0
    pool = {}

    def set_capacity(self, c):
        self.capacity = c

    def get(self, key) -> Worker:
        return self.pool.get(key)

    def add(self, obj):
        if self.allocated >= self.capacity:
            return False, ""
        key = f"worker-{self.allocated}"
        self.pool[key] = obj
        self.allocated += 1
        return True, key

    def remove(self, key):
        if key in self.pool:
            self.pool.pop(key)
            self.allocated -= 1
        return True

    def clear_all(self):
        self.pool = {}
        self.allocated = 0


if __name__ == '__main__':
    p = FixedPool()
    p.set_capacity(1)
    p.add("cc", "cc")
    p.add("ccc", "cc")

    print(p.allocated)




def on_error(wsapp, err):
print("EXAMPLE error encountered: ", err)


# 收到websocket消息的处理
def on_message(ws, message):
    if message == "":
        return
    temp_result = json.loads(message)
print(temp_result)


#!/usr/bin/env python
# coding:utf-8

import datetime
import os
import threading
import time
import json
import base64
import hashlib
import websocket
import gradio as gr

default_addr = "ws://localhost:1888/backup.0/private/chatgpt"
    class WebsocketWrapper(threading.Thread):
    def __init__(self, url):
        super(WebsocketWrapper, self).__init__()
        self.daemon = True
        self.ws = websocket.WebSocketApp(url, on_open=on_open)

    def run(self) -> None:
        self.ws.run_forever()
        print("Done")

    def keep_alive(self):
        pass


def connect(api_key, add=default_addr):
    if api_key:
        os.environ["OPENAI_API_KEY"] = api_key
        # vectorstore = get_weaviate_store()
        # qa_chain = get_new_chain1(vectorstore)
        os.environ["OPENAI_API_KEY"] = ""
        # return qa_chain


def check_and_connect(key, addr):
    # todo
if not addr:
        # check url todo
        return "please specify websocket url... ", -1

    return "connected %s" % addr, None

def on_open(ws):
    ws.send(construct_req(1))
def create_connection(key, addr, status):
    history = []
    init_msg = "connecting ws..."
    print(init_msg)

    # todo call ws create functions
    #
    msg, err = check_and_connect(key, addr)
    output = {"question": init_msg, "chat_history": history, "answer": msg}

    answer = output["answer"]
    history.append((init_msg, answer))
    status = not status

    # create ws
    # request_data_str = json.load(a)
    # auth_request_url = build_auth_request_url(request_url, "GET", APIKey, APISecret)
    ws = WebsocketWrapper(addr)
    ws.start()
    ws.ws.send(construct_req(1))
    # ws.connect(request_url)
    status = None

    return history, history, gr.Button.update("立即连接", interactive=False), gr.Button.update("取消", interactive=True)


count = 0
def construct_req(status=1):
    global count
    request_data_str = open("sample.json", 'rb').read()
    r = json.loads(request_data_str)
    r['header']['status'] = status
    global count, max_count
    count += 1
    print(count)
    if count >= 30:
        r['header']['status'] = 2
        r['payload']['message']['status'] = 2
    return json.dumps(r)


def cancel_connection():
    # todo cancel connection
    return gr.Button.update("立即连接", interactive=True), gr.Button.update("取消", interactive=False)


def chat(inp, history, agent):
    history = history or []
    if agent is None:
        history.append((inp, "Please paste your OpenAI key to use"))
        return history, history
    print("\n==== date/time: " + str(datetime.datetime.now()) + " ====")
    print("inp: " + inp)
    history = history or []
    output = agent({"question": inp, "chat_history": history})
    answer = output["answer"]
    history.append((inp, answer))
    print(history)
    return history, history


def app():
    block = gr.Blocks(css=".gradio-container {background-color: lightgray}")

    with block:
        with gr.Row():
            gr.Markdown("<h3><center>AILab Demo Bot AI</center></h3>")
            with gr.Column():
                openai_api_key_textbox = gr.Textbox(
                    placeholder="Paste your OpenAI API key (sk-...)",
                    show_label=False,
                    lines=1,
                    type="password",
                )
                addr = gr.Textbox(
                    default_addr,
                    placeholder="Paste your Service URL",
                    show_label=False,

                    lines=1, type="text", elem_id="addr"
                )
            with gr.Column():
                cnt = gr.Button(value="立即连接", variant="primary", elem_id="cnt")
                cancel = gr.Button(value="取消", elem_id="cancel", interactive=False)

        chatbot = gr.Chatbot()
        with gr.Column():
            with gr.Row():
                message = gr.Textbox(
                    label="What's your question?",
                    placeholder="What's the answer to life, the universe, and everything?",
                    lines=1,
                )
                submit = gr.Button(value="Send", variant="secondary").style(full_width=False)

        gr.Examples(
            examples=[
                "What are agents?",
                "How do I summarize a long document?",
                "What types of memory exist?",
            ],
            inputs=message,
        )

        gr.HTML(
            """
        This simple application is an implementation of ChatGPT but over an external dataset (in this case, the LangChain documentation)."""
        )

        gr.HTML(
            "<center>Powered by <a href='https://github.com/iflytek/ailab'>AILab 🦜️🔗</a></center>"
        )
        state = gr.State()
        agent_state = gr.State()
        cnt_state = gr.State(False)
        submit.click(chat, inputs=[message, state, agent_state], outputs=[chatbot, state])
        message.submit(chat, inputs=[message, state, agent_state], outputs=[chatbot, state])
        cnt.click(create_connection, inputs=[openai_api_key_textbox, addr, cnt_state],
                  outputs=[chatbot, state, cnt, cancel])
        cancel.click(cancel_connection, None, outputs=[cnt, cancel])

    block.launch(debug=True)


if __name__ == '__main__':
    app()



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: workers
@time: 2023/03/02
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.
import abc
import threading
from abc import ABC
from typing import Any
import queue


class InferClass(ABC):
    @abc.abstractmethod
    def predict(self, *args, **kwargs) -> (object, bool):
        pass

    def setHandle(self, hdl):
        self.handle = hdl


class Worker(threading.Thread):
    def __init__(self, name=None, _type="thread", nums=1,
                 context={}):
        threading.Thread.__init__(self)
        self.name = name
        self._type = _type
        self.nums = nums
        self.context = context
        self.in_q = queue.Queue()
        self.out_q = queue.Queue()
        self.infer_class = None
        self.infer_func = None
        self.callback_fn = None
        self.is_stopping = False

    def stop(self):
        self.is_stopping = True

    def register_infer_class(self, instance):
        if not isinstance(isinstance, InferClass):
            pass
        self.infer_class = instance

    def register_infer_func(self, infer):
        self.infer_func = infer

    def register_callback(self, cb):
        self.callback_fn = cb

    def setHandle(self, hdl):
        self.infer_class.setHandle(hdl)

    def create(self, params={}):
        pass

    def run(self):
        if self.infer_class == None:
            print("not register infer class yet")
        else:
            print("infer class ready")

        while not self.is_stopping:
            try:
                req = self.in_q.get(timeout=3)
            except Exception as e:
                continue
            output, all_done = self.infer_class.predict(req=req)
            if all_done:
                print(" this thread completed...")
                break
            # 一旦这个数据推理完



#!/usr/bin/env python
# coding:utf-8
""" 
@author: nivic ybyang7
@license: Apache Licence 
@file: ws_client
@time: 2023/03/04
@contact: ybyang7@iflytek.com
@site:  
@software: PyCharm 

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛ 
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.

import json
import base64
import hashlib
import time

import websocket


def readb64(index, encoded_data):
    # img = cv2.imdecode(nparr, cv2.IMREAD_COLOR)
    # return img
    b = base64.b64decode(encoded_data)
    print(hashlib.md5(b).hexdigest())
    print(len(b))
    # a = open(str(index) + ".jpg", "wb")
    # a.write(b)
    # a.close()
    return b.decode("utf-8")


def on_error(wsapp, err):
    print("EXAMPLE error encountered: ", err)


# 收到websocket消息的处理
def on_message(ws, message):
    if message == "":
        return
    temp_result = json.loads(message)
    print(temp_result)
    # print("响应数据:{}\n".format(temp_result))
    header = temp_result.get('header')
    if header is None:
        return 2, "失败"
    code = header.get('code')
    if header is None or code != 0:
        print("获取结果失败，请根据code查证问题原因:, %s" % code)
        return 2, "失败"
    text = ''
    if "payload" in temp_result:
        i = temp_result['payload']['response']['text']
        index = temp_result['payload']['response']['seq']
        text = readb64(index, i)
        print(text)

    # print("sid:{}".format(header.get('sid')))
    status = header.get('status')
    if status == 1:
        print("dddcccc")
        ws.send(construct_req(1))

    # print('status:{}\n'.format(status))
    return int(status), text


count = 0
max_count = 30


def construct_req(status=1):
    request_data_str = open("sample.json", 'rb').read()
    r = json.loads(request_data_str)
    r['header']['status'] = status
    global count, max_count
    count += 1
    print(count)
    if count >= 180:
        r['header']['status'] = 2
        r['payload']['message']['status'] = 2
    return json.dumps(r)


def on_open(ws):
    ws.send(construct_req(1))


def on_close(ws, code, reason):
    print("code", code, reason)


def request(request_url, APIKey=None, APISecret=None):
    # request_data_str = json.load(a)
    # auth_request_url = build_auth_request_url(request_url, "GET", APIKey, APISecret)
    ws = websocket.WebSocketApp(request_url, on_open=on_open, on_message=on_message, on_error=on_error,
                                on_close=on_close)
    # ws.connect(request_url)
    ws.run_forever(ping_interval=2)
    status = None
    # while status != 2 :
    #    status = on_message(ws, ws.recv())


if __name__ == '__main__':
    url = "ws://localhost:1888/backup.0/private/chatgpt"
    request(url)



#!/usr/bin/env python
# coding:utf-8
"""
@author: nivic ybyang7
@license: Apache Licence
@file: struct.py
@time: 2023/03/03
@contact: ybyang7@iflytek.com
@site:
@software: PyCharm

# code is far away from bugs with the god animal protecting
    I love animals. They taste delicious.
              ┏┓      ┏┓
            ┏┛┻━━━┛┻┓
            ┃      ☃      ┃
            ┃  ┳┛  ┗┳  ┃
            ┃      ┻      ┃
            ┗━┓      ┏━┛
                ┃      ┗━━━┓
                ┃  神兽保佑    ┣┓
                ┃　永无BUG！   ┏┛
                ┗┓┓┏━┳┓┏┛
                  ┃┫┫  ┃┫┫
                  ┗┻┛  ┗┻┛
"""

#  Copyright (c) 2022. Lorem ipsum dolor sit amet, consectetur adipiscing elit.
#  Morbi non lorem porttitor neque feugiat blandit. Ut vitae ipsum eget quam lacinia accumsan.
#  Etiam sed turpis ac ipsum condimentum fringilla. Maecenas magna.
#  Proin dapibus sapien vel ante. Aliquam erat volutpat. Pellentesque sagittis ligula eget metus.
#  Vestibulum commodo. Ut rhoncus gravida arcu.

from xsf_pb2 import *
from google.protobuf import text_format

PEERADDR = "PeerAddr"


class Data(object):
    def __init__(self, dm: DataMeta):
        self.dm = dm

    def append(self, b):
        self.dm.data += b

    def data(self):
        return self.dm.data

    def set_param(self, k, v):
        self.dm.desc[k] = v

    def get_param(self, k):
        return self.dm.desc[k]


class Req(object):
    def __init__(self, rd: ReqData):
        self.rd = rd

    def set_op(self, op):
        self.rd.op = op

    def size(self):
        if self.rd != None:
            return self.rd.Size()
        return -1

    def get_sess(self):
        return self.rd.s

    def get_peer_ip(self):
        sm = self.get_sess()
        if len(sm) == 0:
            return "", False
        return sm[PEERADDR], True

    def set_req(self, rd: ReqData):
        self.rd = rd

    def set_param(self, k, v):
        if self.rd.param == None:
            self.rd.param = {}
        self.rd.param[k] = v

    def get_param(self, k):
        if k in self.rd.param:
            return self.rd.param[k], True
        return None, False

    def get_all_param(self):
        return self.rd.param

    def append(self, b, desc):
        self.rd.data.append(DataMeta(data=b, desc=desc))

    def append_data(self, d: Data):
        self.rd.data.append(d.dm)

    def session(self, s: str):
        sess = Session()
        text_format.Parse(s, sess)
        if self.rd.s != None and len(self.rd.s.t) > 0:
            sess.t = self.rd.s.t
        if self.rd.s.sess != None:
            sess.sess = self.rd.s.sess
        self.rd.S = sess

    # 追加session描述
    def append_session(self, k, v):
        if self.rd.s.sess == None:
            self.rd.s.sess = {}
        self.rd.s.sess[k] = v

    def set_handle(self, handle):
        self.rd.s.h = handle

    def handle(self):
        if self.rd.s == None:
            return ""
        return self.rd.s.h

    def set_trace_id(self,i):
        self.rd.s.t = i

    def trace_id(self):
        if self.rd.s == None:
            return ""
        return self.rd.s.t

    def req(self):
        return self.rd

    def op(self):
        return self.rd.op

    def data(self):
        dm = Data()
        emty = True
    #todo
    #todo

class Res(object):
    def __init__(self, rs: ResData):
        self.rd = rs


def NewReq():
    rd = ReqData(s=Session(sess={}), param={})
    req = Req(rd)
    return req


def NewData():
    dm = DataMeta(desc={})
    d = Data(dm)


def NewRes():
    rd = ResData(s=Session(sess={}), param={})
    rs = Res(rd)
    return rs


if __name__ == '__main__':
    a = NewReq()
    print(a.get_sess())
